@@ -1,7 +1,7 @@
 package Tk::ROTextHighlight;
 
 use vars qw($VERSION);
-$VERSION = '1.0.5';
+$VERSION = '1.1.0';
 use base qw(Tk::Derived Tk::ROText);
 use strict;
 use Storable;
@@ -51,7 +51,7 @@ sub jumpToMatchingChar  #ADDED 20060630 JWT TO CAUSE ^p TO WORK LIKE VI & SUPERT
 	if ($pm >= 0)
 	{
 		my $prevMatch = $cw->index('insert');
-		$prevMatch .= '.0'  unless ($prevMatch =~ /\./);
+		$prevMatch .= '.0'  unless ($prevMatch =~ /\./o);
 		$cw->markSet('insert', $cw->index('MyMatch'));
 		$cw->see('insert');
 		$cw->markSet('MyMatch', $prevMatch);
@@ -122,12 +122,12 @@ sub doAutoIndent {
 #			if ($s =~ /\S/)  #JWT: UNCOMMENT TO CAUSE SUBSEQUENT BLANK LINES TO NOT BE AUTOINDENTED.
 #			{
 				#$s =~ /^(\s+)/;  #CHGD. TO NEXT 20060701 JWT TO FIX "e" BEING INSERTED INTO LINE WHEN AUTOINDENT ON?!
-				$s =~ /^(\s*)/;
+				$s =~ /^(\s*)/o;
 				if ($1) {
 					$cw->insert('insert', $1);
 				}
 				$cw->insert('insert', $cw->cget('-indentchar'))
-						if ($s =~ /\{\s*$/);   #ADDED 20060701 JWT - ADD AN INDENTION IF JUST OPENED A BLOCK!
+						if ($s =~ /\{\s*$/o);   #ADDED 20060701 JWT - ADD AN INDENTION IF JUST OPENED A BLOCK!
 #			}
 		}
 	}
@@ -328,7 +328,7 @@ sub highlightPlugInit {
 		my $var;
 		foreach my $i (0..$lastMenuIndex)
 		{
-			if ($ViewSyntaxMenu->type($i) =~ /radiobutton/)
+			if ($ViewSyntaxMenu->type($i) =~ /radiobutton/o)
 			{
 				$var = $ViewSyntaxMenu->entrycget($i, '-variable');
 				tie $$var,'Tk::Configure',$cw,'-syntax';
@@ -346,11 +346,17 @@ sub highlightPlugInit {
 sub highlightPlugList {
 	my $cw = shift;
 	my @ml = ();
+	my $haveKate = 0;
 	foreach my $d (@INC) {
 		my @fl = <$d/Tk/TextHighlight/*.pm>;
 		foreach my $file (@fl) {
 			my ($name, $path, $suffix) = fileparse($file, "\.pm");
-			if (($name ne 'None') and ($name ne 'Template')) {
+			if ($name eq 'Kate') {   #JWT:ADDED THIS PART OF CONDITIONAL 20160118:
+				eval 'use Syntax::Highlight::Engine::Kate; $haveKate = 1; 1'  unless ($haveKate);
+				if ($haveKate) {
+					unless (grep { ($name eq $_) } @ml) { push(@ml, $name); };
+				}
+			} elsif (($name ne 'None') and ($name ne 'Template')) {
 				#avoid duplicates
 				unless (grep { ($name eq $_) } @ml) { push(@ml, $name); };
 			}
@@ -399,7 +405,7 @@ sub InsertKeypress {
 	if ($char ne '') {
 		my $index = $cw->index('insert');
 		my $line = $cw->linenumber($index);
-		if ($char =~ /^\S$/ and !$cw->OverstrikeMode and !$cw->tagRanges('sel')) {
+		if ($char =~ /^\S$/o and !$cw->OverstrikeMode and !$cw->tagRanges('sel')) {
 			my $undo_item = $cw->getUndoAtIndex(-1);
 			if (defined($undo_item) &&
 				($undo_item->[0] eq 'delete') &&
@@ -422,7 +428,7 @@ sub linenumber {
 	my ($cw, $index) = @_;
 	if (not defined($index)) { $index = 'insert'; }
 	my $id = $cw->index($index);
-	my ($line, $pos ) = split(/\./, $id);
+	my ($line, $pos ) = split(/\./o, $id);
 	return $line;
 }
 
@@ -518,7 +524,7 @@ sub matchoptions {
 		if (ref($o)) {
 			@op = @$o;
 		} else {
-			@op = split(/\s+/, $o);
+			@op = split(/\s+/o, $o);
 		}
 		$cw->tagConfigure('Match', @op);
 	}
@@ -804,7 +810,7 @@ sub fetchKateInfo   #FETCH LISTS OF KATE LANGUAGES AND FILE EXTENSION PATTERNS W
 				}
 				elsif ($inExtensions)
 				{
-					if (/\'([^\']+)\'\s*\=\>\s*\[\'([^\']+)\'/)
+					if (/\'([^\']+)\'\s*\=\>\s*\[\'([^\']+)\'/o)
 					{
 						my $one = '^'.$1.'$';
 						my $two = $2;
@@ -819,7 +825,7 @@ sub fetchKateInfo   #FETCH LISTS OF KATE LANGUAGES AND FILE EXTENSION PATTERNS W
 				}
 				elsif ($inSyntaxes)
 				{
-					if (/\'([^\']+)\'\s*\=\>\s*\[\'([^\']+)\'/)
+					if (/\'([^\']+)\'\s*\=\>\s*\[\'([^\']+)\'/o)
 					{
 						$syntaxHash{$1} = $2;
 					}
@@ -856,14 +862,14 @@ sub addKate2ViewMenu    #ADD ALL KATE-LANGUAGES AS OPTIONS TO THE "View" MENU:
 	my $kateIndx = 'end';
 	foreach my $i (0..$lastMenuIndex)
 	{
-		if ($ViewSyntaxMenu->type($i) =~ /radiobutton/)
+		if ($ViewSyntaxMenu->type($i) =~ /radiobutton/o)
 		{
 			$var = $ViewSyntaxMenu->entrycget($i, '-variable');
 			tie $$var,'Tk::Configure',$cw,'-syntax';
 			if ($ViewSyntaxMenu->entrycget($i, '-label') eq 'Kate')
 			{
 				$ViewSyntaxMenu->delete($i);   #REMOVE THE "Kate" ENTRY, SINCE WE'RE ADDING KATE STUFF SEPARATELY!
-				$kateIndx = $i;    #SAVE IT'S MENU-LOCATION SO WE CAN INSERT THE KATE MENU TREE THERE.
+#UNCOMMENT TO INSERT KATE MENUS IN ALPHABETICAL ORDER IN VIEW MENU:								$kateIndx = $i;    #SAVE IT'S MENU-LOCATION SO WE CAN INSERT THE KATE MENU TREE THERE.
 				last;
 			}
 		}
