@@ -1,7 +1,7 @@
 package Tk::TextHighlight;
 
 use vars qw($VERSION);
-$VERSION = '1.0.5';
+$VERSION = '1.1.0';
 use base qw(Tk::Derived Tk::TextUndo);
 use strict;
 use Storable;
@@ -134,12 +134,12 @@ sub ClassInit   #JWT: ADDED FOR VI-LIKE Control-P JUMP TO MATCHING BRACKET FEATU
 
 	# reset default Tk::Text binds
 	$w->bind($class,	'<Control-p>', sub {} );
-	$w->bind($class,	'<Tab>', 'insertTab' );    #ADDED TO ALLOW INSERTION OF TABS OR SPACES!
 	$w->bind($class,	'<Alt-Tab>', 'insertTabChar' );    #ADDED TO ALLOW INSERTION OF TABS OR SPACES!
 	$w->bind($class, '<Shift-BackSpace>', 'doShiftBackSpace' );   #DOESN'T SEEM TO WORK?!?!?!
 	$w->bind($class, '<Shift-Delete>', 'doShiftDelete' );
 	$w->bind($class, '<Control-Delete>', 'deleteToEndofLine' );
-	$w->bind($class, '<Shift-Tab>', 'deleteToEndofLine' );   #DOESN'T SEEM TO WORK?!?!?!
+	$w->bind($class, '<Control-Tab>', 'deleteToEndofLine' );   #DOESN'T SEEM TO WORK?!?!?!
+	$w->bind($class,	'<Tab>', 'insertTab' );    #ADDED TO ALLOW INSERTION OF TABS OR SPACES!
 	$w->bind($class, '<Control-BackSpace>', 'doShiftBackSpace' );
 	return $class;
 }
@@ -407,7 +407,7 @@ sub highlightPlugInit {
 		my $var;
 		foreach my $i (0..$lastMenuIndex)
 		{
-			if ($ViewSyntaxMenu->type($i) =~ /radiobutton/)
+			if ($ViewSyntaxMenu->type($i) =~ /radiobutton/o)
 			{
 				$var = $ViewSyntaxMenu->entrycget($i, '-variable');
 				tie $$var,'Tk::Configure',$cw,'-syntax';
@@ -425,11 +425,17 @@ sub highlightPlugInit {
 sub highlightPlugList {
 	my $cw = shift;
 	my @ml = ();
+	my $haveKate = 0;
 	foreach my $d (@INC) {
 		my @fl = <$d/Tk/TextHighlight/*.pm>;
 		foreach my $file (@fl) {
 			my ($name, $path, $suffix) = fileparse($file, "\.pm");
-			if (($name ne 'None') and ($name ne 'Template')) {
+			if ($name eq 'Kate') {   #JWT:ADDED THIS PART OF CONDITIONAL 20160118:
+				eval 'use Syntax::Highlight::Engine::Kate; $haveKate = 1; 1'  unless ($haveKate);
+				if ($haveKate) {
+					unless (grep { ($name eq $_) } @ml) { push(@ml, $name); };
+				}
+			} elsif (($name ne 'None') and ($name ne 'Template')) {
 				#avoid duplicates
 				unless (grep { ($name eq $_) } @ml) { push(@ml, $name); };
 			}
@@ -478,7 +484,7 @@ sub InsertKeypress {
 	if ($char ne '') {
 		my $index = $cw->index('insert');
 		my $line = $cw->linenumber($index);
-		if ($char =~ /^\S$/ and !$cw->OverstrikeMode and !$cw->tagRanges('sel')) {
+		if ($char =~ /^\S$/o and !$cw->OverstrikeMode and !$cw->tagRanges('sel')) {
 			my $undo_item = $cw->getUndoAtIndex(-1);
 			if (defined($undo_item) &&
 				($undo_item->[0] eq 'delete') &&
@@ -501,7 +507,7 @@ sub linenumber {
 	my ($cw, $index) = @_;
 	if (not defined($index)) { $index = 'insert'; }
 	my $id = $cw->index($index);
-	my ($line, $pos ) = split(/\./, $id);
+	my ($line, $pos ) = split(/\./o, $id);
 	return $line;
 }
 
@@ -597,7 +603,7 @@ sub matchoptions {
 		if (ref($o)) {
 			@op = @$o;
 		} else {
-			@op = split(/\s+/, $o);
+			@op = split(/\s+/o, $o);
 		}
 		$cw->tagConfigure('Match', @op);
 	}
@@ -883,7 +889,7 @@ sub fetchKateInfo   #FETCH LISTS OF KATE LANGUAGES AND FILE EXTENSION PATTERNS W
 				}
 				elsif ($inExtensions)
 				{
-					if (/\'([^\']+)\'\s*\=\>\s*\[\'([^\']+)\'/)
+					if (/\'([^\']+)\'\s*\=\>\s*\[\'([^\']+)\'/o)
 					{
 						my $one = '^'.$1.'$';
 						my $two = $2;
@@ -898,7 +904,7 @@ sub fetchKateInfo   #FETCH LISTS OF KATE LANGUAGES AND FILE EXTENSION PATTERNS W
 				}
 				elsif ($inSyntaxes)
 				{
-					if (/\'([^\']+)\'\s*\=\>\s*\[\'([^\']+)\'/)
+					if (/\'([^\']+)\'\s*\=\>\s*\[\'([^\']+)\'/o)
 					{
 						$syntaxHash{$1} = $2;
 					}
@@ -935,14 +941,14 @@ sub addKate2ViewMenu    #ADD ALL KATE-LANGUAGES AS OPTIONS TO THE "View" MENU:
 	my $kateIndx = 'end';
 	foreach my $i (0..$lastMenuIndex)
 	{
-		if ($ViewSyntaxMenu->type($i) =~ /radiobutton/)
+		if ($ViewSyntaxMenu->type($i) =~ /radiobutton/o)
 		{
 			$var = $ViewSyntaxMenu->entrycget($i, '-variable');
 			tie $$var,'Tk::Configure',$cw,'-syntax';
 			if ($ViewSyntaxMenu->entrycget($i, '-label') eq 'Kate')
 			{
 				$ViewSyntaxMenu->delete($i);   #REMOVE THE "Kate" ENTRY, SINCE WE'RE ADDING KATE STUFF SEPARATELY!
-				$kateIndx = $i;    #SAVE IT'S MENU-LOCATION SO WE CAN INSERT THE KATE MENU TREE THERE.
+#UNCOMMENT TO INSERT KATE MENUS IN ALPHABETICAL ORDER IN VIEW MENU:				$kateIndx = $i;    #SAVE IT'S MENU-LOCATION SO WE CAN INSERT THE KATE MENU TREE THERE.
 				last;
 			}
 		}
